@@ -3,11 +3,10 @@
 ;; Author: Duncan Britt
 ;; Contact: https://github.com/Duncan-Britt/directory-slideshow/issues
 ;; URL: https://github.com/Duncan-Britt/directory-slideshow
-;; Package-Version: 20250828.1527
-;; Package-Revision: 2b18d6bd1b74
+;; Package-Version: 20251218.554
+;; Package-Revision: a54e6bc923f1
 ;; Package-Requires: ((emacs "29.4"))
 ;; Keywords: multimedia
-;; URL: https://github.com/Duncan-Britt/directory-slideshow
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -113,7 +112,7 @@
 
 (defgroup directory-slideshow nil            ;; ┌──────────────────┐
   "Display directory contents as slideshow." ;; │ Custom Variables │
-  :group 'convenience)                       ;; └──────────────────┘
+  :group 'applications)                      ;; └──────────────────┘
 
 (defcustom directory-slideshow-use-default-bindings t
   "Whether to use the default keybindings for directory-slideshow mode."
